#ifndef NT2_INCLUDE_FUNCTIONS_FUZZY_DEFINITELY_NOT_EQUAL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_FUZZY_DEFINITELY_NOT_EQUAL_HPP_INCLUDED

#include <nt2/fuzzy/include/functions/fuzzy_definitely_not_equal.hpp>

#endif
